"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var vitest_1 = require("vitest");
var MetricsConfiguration_1 = require("./MetricsConfiguration");
var MetricsParser_1 = require("./MetricsParser");
(0, vitest_1.describe)("MetricsParser", function () {
    var src = "\n    import { describe, it } from \"jest\";\n\n    describe(\"test\", () => {\n        it(\"test case\", () => {\n          function isVue(languageId: string) {\n            return languageId == \"vue\";\n          }\n\n          function isHTML(languageId: string) {\n            return languageId == \"html\";\n          }\n\n          function isHTMLLike(languageId: string) {\n            return this.isVue(languageId) || this.isHTML(languageId);\n          }\n        })\n    });\n  ";
    (0, vitest_1.it)("IgnoredFunctionNames is empty by default", function () {
        var result = MetricsParser_1.MetricsParser.getMetricsFromText("test.spec.ts", src, __assign({}, MetricsConfiguration_1.MetricsConfiguration), 99);
        (0, vitest_1.expect)(result.metrics.getCollectedComplexity()).toBe(9);
    });
    (0, vitest_1.it)("IgnoredFunctionNames can be overridden", function () {
        var result = MetricsParser_1.MetricsParser.getMetricsFromText("test.spec.ts", src, __assign(__assign({}, MetricsConfiguration_1.MetricsConfiguration), { IgnoredFunctionNames: [""] }), 99);
        (0, vitest_1.expect)(result.metrics.getCollectedComplexity()).toBe(9);
    });
    (0, vitest_1.it)("IgnoredFunctionNames can be null", function () {
        var withNullConfig = MetricsParser_1.MetricsParser.getMetricsFromText("test.spec.ts", src, __assign(__assign({}, MetricsConfiguration_1.MetricsConfiguration), { IgnoredFunctionNames: null }), 99);
        (0, vitest_1.expect)(withNullConfig.metrics.getCollectedComplexity()).toBe(9);
    });
    (0, vitest_1.it)("IgnoredFunctionNames can be configured to ignore a given function call", function () {
        var withDescribeExcluded = MetricsParser_1.MetricsParser.getMetricsFromText("test.spec.ts", src, __assign(__assign({}, MetricsConfiguration_1.MetricsConfiguration), { IgnoredFunctionNames: ["describe"] }), 99);
        (0, vitest_1.expect)(withDescribeExcluded.metrics.getCollectedComplexity()).toBe(8);
    });
    (0, vitest_1.it)("IgnoredFunctionNames can be configured to ignore multiple function calls", function () {
        var withDescribeExcluded = MetricsParser_1.MetricsParser.getMetricsFromText("test.spec.ts", src, __assign(__assign({}, MetricsConfiguration_1.MetricsConfiguration), { IgnoredFunctionNames: ["describe", "it"] }), 99);
        (0, vitest_1.expect)(withDescribeExcluded.metrics.getCollectedComplexity()).toBe(7);
    });
});
//# sourceMappingURL=MetricsParser.spec.js.map